@@ -1,8 +1,15 @@
 from django.conf.global_settings import *
 import os
 
+DEBUG = True
+
+STATIC_ROOT = MEDIA_ROOT = os.path.join(os.path.dirname(__file__), 'static')
+
+STATICFILES_DIRS = (
+    os.path.join(os.path.dirname(__file__), 'staticfiles_dir'),
+    ("prefix", os.path.join(os.path.dirname(__file__), 'staticfiles_dir_with_prefix')),
+)
 
-STATIC_ROOT = MEDIA_ROOT = os.path.join(os.path.dirname(__file__), 'media')
 INSTALLED_APPS = (
     "coffeescript",
 )
